"""Blender-basico's Libsass compiler for django-pipeline.

It's just like https://github.com/sonic182/libsasscompiler,
but allows compiling SASS that imports Basico's SASS from other apps' static,
adding a custom `COMPILERS_INCLUDED_APP_STATIC` `PIPELINE` setting.
"""
import logging
import os

from django.conf import settings
from django.contrib.staticfiles import finders
from pipeline.compilers import CompilerBase
import codecs
import sass
logger = logging.getLogger(__name__)


class LibSassCompilerWithAppStatic(CompilerBase):
    """Compiler that uses libsass and includes static dirs of multiple apps.

    Use COMPILERS_INCLUDED_APP_STATIC in settings.PIPELINE to list apps,
    static directories of which must be included during compilation.
    """

    output_extension = 'css'

    def _get_include_paths(self):
        include_paths = set()
        for path in settings.PIPELINE.get('COMPILERS_APP_STATIC', []):
            result = finders.find(path)
            if not result:
                logger.error('Unable to find %s', path)
                return
            include_paths.add(os.path.dirname(result))
        return include_paths

    def match_file(self, filename):
        """Check files extension to use them."""
        return filename.endswith(('.scss', '.sass'))

    def compile_file(self, infile, outfile, outdated=False, force=False):
        """Process sass file."""
        include_paths = self._get_include_paths()

        myfile = codecs.open(outfile, 'w', 'utf-8')

        if settings.DEBUG:
            myfile.write(sass.compile(filename=infile,
                                      include_paths=include_paths))
        else:
            myfile.write(sass.compile(filename=infile,
                                      output_style='compressed',
                                      include_paths=include_paths))
        return myfile.close()



from django.shortcuts import render
from django.contrib import messages


def index(request):
    return render(request, 'blender_basico/base.html', {})


def index_with_alert(request):
    messages.add_message(request, messages.INFO, 'This is an info message.')
    messages.add_message(request, messages.SUCCESS, 'This is a success message.')
    return render(request, 'blender_basico/base.html')



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['blender_basico']

package_data = \
{'': ['*'],
 'blender_basico': ['static/blender_basico/fonts/*',
                    'static/blender_basico/images/*',
                    'static/blender_basico/scripts/tutti/*',
                    'static/blender_basico/scripts/vendor/*',
                    'static/blender_basico/styles/*',
                    'static/blender_basico/styles/bootstrap/*',
                    'static/blender_basico/styles/bootstrap/mixins/*',
                    'static/blender_basico/styles/bootstrap/utilities/*',
                    'static/blender_basico/styles/bootstrap/vendor/*',
                    'templates/blender_basico/_footer.html',
                    'templates/blender_basico/_footer.html',
                    'templates/blender_basico/_footer.html',
                    'templates/blender_basico/_navbar.html',
                    'templates/blender_basico/_navbar.html',
                    'templates/blender_basico/_navbar.html',
                    'templates/blender_basico/base.html',
                    'templates/blender_basico/base.html',
                    'templates/blender_basico/base.html']}

install_requires = \
['django-pipeline>=2,<3',
 'django>=2.1,<3.0',
 'jsmin>=2.2,<3.0',
 'libsasscompiler>=0.1.5,<0.2.0',
 'pypugjs>=5.9.8,<6.0.0']

entry_points = \
{'console_scripts': ['update-bwa = tools:update']}

setup_kwargs = {
    'name': 'blender-basico',
    'version': '0.2.0rc2',
    'description': 'Django shared app, featuring essential components for blender.org sites.',
    'long_description': None,
    'author': 'Francesco Siddi',
    'author_email': 'francesco@blender.org',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
